pub enum VariableKind {
Exact(Kind),
Target,
TargetInnerValue,
TargetInnerKey,
}Variants
Exact(Kind)
An exact Kind means this variable is guaranteed to always contain
a value that resolves to this kind.
For example, in map_keys, it is known that the first (and only)
variable the closure takes will be a Kind::bytes().
Target
The variable Kind is inferred from the target of the closure.
TargetInnerValue
The variable Kind is inferred from the inner kind of the target of
the closure. This requires the closure target to be a collection type.
TargetInnerKey
The variable Kind is inferred from the key or index type of the
target. If the target is known to be exactly an object, this is always
a Value::bytes(), if it’s known to be exactly an array, it is
a Value::integer(), otherwise it is one of the two.