pub struct Input {
pub parameter_keyword: &'static str,
pub kind: Kind,
pub variables: Vec<Variable>,
pub output: Output,
pub example: Example,
}Expand description
One input variant for a function-closure.
A closure can support different variable input shapes, depending on the type of a given parameter of the function.
For example, the for_each function takes either an Object or an Array
for the value parameter, and the closure it takes either accepts |key, value|, where “key” is always a string, or |index, value| where “index”
is always a number, depending on the parameter input type.
Fields
parameter_keyword: &'static strThe parameter keyword upon which this closure input variant depends on.
kind: KindThe value kind this closure input expects from the parameter.
variables: Vec<Variable>The list of variables attached to this closure input type.
output: OutputThe return type this input variant expects the closure to have.
example: ExampleAn example matching the given input.