pub struct Runner<'a, T> { /* private fields */ }Implementations
Sourceimpl<'a, T> Runner<'a, T>
impl<'a, T> Runner<'a, T>
pub fn new(variables: &'a [Ident], runner: T) -> Self
Sourcepub fn run_key_value(
&self,
ctx: &mut Context<'_>,
key: &str,
value: &Value,
) -> Result<Value, ExpressionError>
pub fn run_key_value( &self, ctx: &mut Context<'_>, key: &str, value: &Value, ) -> Result<Value, ExpressionError>
Run the closure to completion, given the provided key/value pair, and the runtime context.
The provided values are NOT mutated during the run. See map_key or
map_value for mutating alternatives.
Sourcepub fn run_index_value(
&self,
ctx: &mut Context<'_>,
index: usize,
value: &Value,
) -> Result<Value, ExpressionError>
pub fn run_index_value( &self, ctx: &mut Context<'_>, index: usize, value: &Value, ) -> Result<Value, ExpressionError>
Run the closure to completion, given the provided index/value pair, and the runtime context.
The provided values are NOT mutated during the run. See map_key or
map_value for mutating alternatives.
Sourcepub fn map_key(
&self,
ctx: &mut Context<'_>,
key: &mut KeyString,
) -> Result<(), ExpressionError>
pub fn map_key( &self, ctx: &mut Context<'_>, key: &mut KeyString, ) -> Result<(), ExpressionError>
Run the closure to completion, given the provided key, and the runtime context.
The provided key is MUTATED by overwriting the key with the return value of the closure after completion.
See run_key_value and run_index_value for immutable alternatives.
Sourcepub fn map_value(
&self,
ctx: &mut Context<'_>,
value: &mut Value,
) -> Result<(), ExpressionError>
pub fn map_value( &self, ctx: &mut Context<'_>, value: &mut Value, ) -> Result<(), ExpressionError>
Run the closure to completion, given the provided value, and the runtime context.
The provided value is MUTATED by overwriting the value with the return value of the closure after completion.
See run_key_value and run_index_value for immutable alternatives.